import {Component,NgModule, Input, ViewContainerRef, ViewChild, ReflectiveInjector, ComponentFactoryResolver} from '@angular/core';
import DynamicGridComponent from "././grid-dynamic-component";
import {BrowserModule} from '@angular/platform-browser'

@Component({
  selector: 'dynamic-component',
  entryComponents:[DynamicGridComponent],  
  template: `
  <div #dialog></div>
  `
})
export class DynamicComponent {
  currentComponent = null;
  public resolver: ComponentFactoryResolver;

  @ViewChild('dialog', { read: ViewContainerRef }) dynamicComponentContainer: ViewContainerRef;
   


  @Input() set showOnInit(data) {
    if (!data) {
      return;
    }

    // Inputs need to be in the following format to be resolved properly
    let inputProviders = [{ provide: 'showOnInit', useValue: data }];
    let resolvedInputs = ReflectiveInjector.resolve(inputProviders);
    
    // We create an injector out of the data we want to pass down and this components injector
    let injector = ReflectiveInjector.fromResolvedProviders(resolvedInputs, this.dynamicComponentContainer.parentInjector);
    
    // We create a factory out of the component we want to create
    let factory = this.resolver.resolveComponentFactory(DynamicGridComponent);
    
    // We create the component using the factory and the injector
    let component = factory.create(injector);
    
    // We insert the component into the dom container
    this.dynamicComponentContainer.insert(component.hostView);
          
  }
  
  constructor(private resolve: ComponentFactoryResolver) {
    this.resolver = resolve;
  }

}
 